@@ -145,32 +145,12 @@ pango_font_map_fontset_add_fonts (PangoFontMap          *fontmap,
 				  PangoFontDescription  *desc,
 				  const char            *family)
 {
-  char **aliases;
-  int n_aliases;
-  int j;
   PangoFont *font;
 
-  pango_lookup_aliases (family,
-			&aliases,
-			&n_aliases);
-
-  if (n_aliases)
-    {
-      for (j = 0; j < n_aliases; j++)
-	{
-	  pango_font_description_set_family_static (desc, aliases[j]);
-	  font = pango_font_map_load_font (fontmap, context, desc);
-	  if (font)
-	    pango_fontset_simple_append (fonts, font);
-	}
-    }
-  else
-    {
-      pango_font_description_set_family_static (desc, family);
-      font = pango_font_map_load_font (fontmap, context, desc);
-      if (font)
-	pango_fontset_simple_append (fonts, font);
-    }
+  pango_font_description_set_family_static (desc, family);
+  font = pango_font_map_load_font (fontmap, context, desc);
+  if (font)
+    pango_fontset_simple_append (fonts, font);
 }
 
 static PangoFontset *
@@ -184,7 +164,8 @@ pango_font_map_real_load_fontset (PangoFontMap               *fontmap,
   char **families;
   int i;
   PangoFontsetSimple *fonts;
-  static GHashTable *warned_fonts = NULL;
+  static GHashTable *warned_fonts = NULL; /* MT-safe */
+  G_LOCK_DEFINE_STATIC (warned_fonts);
 
   family = pango_font_description_get_family (desc);
   families = g_strsplit (family ? family : "", ",", -1);
@@ -213,6 +194,7 @@ pango_font_map_real_load_fontset (PangoFontMap               *fontmap,
       ctmp1 = pango_font_description_to_string (desc);
       pango_font_description_set_family_static (tmp_desc, "Sans");
 
+      G_LOCK (warned_fonts);
       if (!warned_fonts || !g_hash_table_lookup (warned_fonts, ctmp1))
 	{
 	  if (!warned_fonts)
@@ -225,6 +207,7 @@ pango_font_map_real_load_fontset (PangoFontMap               *fontmap,
 		     "expect ugly output.", ctmp1, ctmp2);
 	  g_free (ctmp2);
 	}
+      G_UNLOCK (warned_fonts);
       g_free (ctmp1);
 
       pango_font_map_fontset_add_fonts (fontmap,
@@ -247,6 +230,7 @@ pango_font_map_real_load_fontset (PangoFontMap               *fontmap,
       pango_font_description_set_variant (tmp_desc, PANGO_VARIANT_NORMAL);
       pango_font_description_set_stretch (tmp_desc, PANGO_STRETCH_NORMAL);
 
+      G_LOCK (warned_fonts);
       if (!warned_fonts || !g_hash_table_lookup (warned_fonts, ctmp1))
 	{
 	  g_hash_table_insert (warned_fonts, g_strdup (ctmp1), GINT_TO_POINTER (1));
@@ -257,7 +241,7 @@ pango_font_map_real_load_fontset (PangoFontMap               *fontmap,
 		     "expect ugly output.", ctmp1, ctmp2);
 	  g_free (ctmp2);
 	}
-
+      G_UNLOCK (warned_fonts);
       g_free (ctmp1);
 
       pango_font_map_fontset_add_fonts (fontmap,
