@@ -49,6 +49,10 @@
  *
  * Needless to say, the list MUST be sorted on the language code.
  */
+/* Sacrificial define to make introspection happy. */
+#ifndef LANGUAGE(x, y, z)
+#define LANGUAGE(x, y, z)
+#endif
 LANGUAGE(
 	 af	/* Afrikaans */,
 	 GLASS,
